"""
django-userextensions library
----------------------------
A user extension module for django.
:copyright: (c) 2019 by David Slusser
:license: GPL-3.0. See LICENSE for more details
"""

__title__ = 'django-userextensions'
__version__ = '0.1.1'
__author__ = 'David Slusser'
__email__ = 'dbslusser@gmail.com'
__license__ = 'GPL-3.0'
__copyright__ = 'Copyright 2019 David Slusser'


default_app_config = 'userextensions.apps.UserExtensionsConfig'
