# Generated by Django 2.2.9 on 2020-01-17 21:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('userextensions', '0002_userpreference_start_page'),
    ]

    operations = [
        migrations.AlterField(
            model_name='theme',
            name='css_file',
            field=models.CharField(blank=True, help_text='path to css file for theme', max_length=255, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='userpreference',
            name='start_page',
            field=models.CharField(blank=True, help_text='url to redirect to after login', max_length=255, null=True),
        ),
    ]
