<div class="container-fluid mt-3 mb-3">
    <span id="clipboardExample1">{{ token }}</span>
    <a href="#" title="copy token" class="cpy ml-3" data-clipboard-target="#clipboardExample1"><i class="fas fa-copy"></i></a>
</div>
